@@ -252,6 +252,14 @@ void bm_menu_free_items(struct bm_menu *menu);
  * @name Menu Properties
  * @{ */
 
+/**
+ * Get the renderer from the bm_menu instance.
+ *
+ * @param menu bm_menu instance which renderer to get.
+ * @return Pointer to bm_renderer instance.
+ */
+const struct bm_renderer* bm_menu_get_renderer(struct bm_menu *menu);
+
 /**
  * Set userdata pointer to bm_menu instance.
  * Userdata will be carried unmodified by the instance.
@@ -289,6 +297,8 @@ const char* bm_menu_get_prefix(struct bm_menu *menu);
 /**
  * Set filter text to bm_menu instance.
  *
+ * The cursor will be automatically placed at the end of the new filter text.
+ *
  * @param menu bm_menu instance where to set filter.
  * @param filter Null terminated C "string" to act as filter. May be set **NULL** for none.
  */
